package com.gprinter.zb;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.OutputStream;

/* loaded from: com_gprinter_zb.jar:com/gprinter/zb/CompressedBitmapOutputStreamZpl.class */
class CompressedBitmapOutputStreamZpl extends CompressedBitmapOutputStreamA {
    private byte previousByteWritten = 0;
    private int previousByteWrittenRepeatCount = 0;
    private static final int[] charMap = {380, 360, 340, 320, 300, 280, 260, 240, 220, 200, 180, 160, 140, 120, 100, 80, 60, 40, 20, 19, 18, 17, 16, 15, 14, 13, 12, 11, 10, 9, 8, 7, 6, 5, 4, 3, 2, 1};
    private static final char[] charVal = {'y', 'x', 'w', 'v', 'u', 't', 's', 'r', 'q', 'p', 'o', 'n', 'm', 'l', 'k', 'j', 'i', 'h', 'g', 'Y', 'X', 'W', 'V', 'U', 'T', 'S', 'R', 'Q', 'P', 'O', 'N', 'M', 'L', 'K', 'J', 'I', 'H', 'G'};

    public CompressedBitmapOutputStreamZpl(OutputStream var1) {
        this.outputStream = var1;
        this.internalEncodedBuffer = new ByteArrayOutputStream();
    }

    @Override // java.io.OutputStream
    public void write(byte[] var1) throws IOException {
        for (byte b : var1) {
            byte[] var3 = extractNibblesFromByte(b);
            writeNibblesToStream(var3);
        }
    }

    @Override // com.gprinter.zb.CompressedBitmapOutputStreamA, java.io.OutputStream, java.io.Flushable
    public void flush() throws IOException {
        if (this.previousByteWrittenRepeatCount > 0) {
            sendBufferedDataToPrinter();
            this.previousByteWrittenRepeatCount = 0;
        }
        super.flush();
    }

    private void writeNibblesToStream(byte[] var1) throws IOException {
        for (byte b : var1) {
            writeNibbleToStream(b);
        }
    }

    private void writeNibbleToStream(byte var1) throws IOException {
        if (this.previousByteWrittenRepeatCount == 0) {
            this.previousByteWritten = var1;
            this.previousByteWrittenRepeatCount++;
        } else {
            if (this.previousByteWritten == var1) {
                this.previousByteWrittenRepeatCount++;
                return;
            }
            sendBufferedDataToPrinter();
            this.previousByteWritten = var1;
            this.previousByteWrittenRepeatCount = 1;
        }
    }

    private void sendBufferedDataToPrinter() throws IOException {
        try {
            computeAndOutput();
        } catch (Exception var2) {
            throw new IOException(var2.getMessage());
        }
    }

    private void computeAndOutput() throws IOException, Exception {
        if (this.previousByteWrittenRepeatCount > 1) {
            int var1 = this.previousByteWrittenRepeatCount / 400;
            int var2 = this.previousByteWrittenRepeatCount % 400;
            for (int var3 = 0; var3 < var1; var3++) {
                bufferAndWrite('z');
            }
            for (int var32 = 0; var32 < charMap.length; var32++) {
                if (var2 >= charMap[var32]) {
                    bufferAndWrite(charVal[var32]);
                    var2 -= charMap[var32];
                }
            }
        }
        bufferAndWrite(Integer.toHexString(this.previousByteWritten & 15).toUpperCase().charAt(0));
    }

    private byte[] extractNibblesFromByte(byte var1) {
        byte[] var2 = {(byte) (((var1 ^ (-1)) >> 4) & 15), (byte) ((var1 ^ (-1)) & 15)};
        return var2;
    }
}
